<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Core\Entry\Pagination
 * @copyright   Copyright (c) 2021, WeCodeArt Framework
 * @since 		3.5
 * @version		5.0.0
 */

namespace WeCodeArt\Core\Entry;

defined( 'ABSPATH' ) || exit();

use WeCodeArt\Markup;
use WeCodeArt\Singleton;

/**
 * Handles single entry pagination
 */
class Pagination {

	use Singleton;

	/**
	 * Send to Constructor
	 */
	public function init() {
        add_filter( 'wp_link_pages_args',   [ $this, 'wp_link_pages_args' ] );
        add_filter( 'wp_link_pages_link',   [ $this, 'wp_link_pages_link' ] );
        add_filter( 'the_content',          [ $this, 'add_pagination' ] );
	}

    /**
     * WP-Link Pages for single
     *
     * @since	unknown
     * @version 5.0.0
     *
     * @return  string
     */
    public function add_pagination( $content ) {
        global $multipage;

        if( is_singular() && 0 !== $multipage ) {
            $content .= wp_link_pages();
        }

        return $content;
    }

    /**
     * WP-Link Pages for paginated posts
     *
     * @since	unknown
     * @version 5.0.0
     *
     * @return  array
     */
    public function wp_link_pages_args( $args ) {
        return wp_parse_args( [
            'before'        => '<nav class="pagination pagination-sm pagination--entry mb-3">',
            'after'         => '</nav>',
            'link_before'   => '<span class="page-link">',
            'link_after'    => '</span>',
            'echo'          => false,
        ], $args );
    }

    /**
     * WP-Link Pages link
     *
     * @since	5.0.0
     * @version 5.0.0
     *
     * @return  string
     */
    public function wp_link_pages_link( $link ) {
        $link = str_replace( 'post-page-numbers', 'page-item text-decoration-none', $link );
        $link = str_replace( 'current', 'active', $link );
        return $link;
    }
}