<?php
/**
 * WeCodeArt Framework
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package		WeCodeArt Framework
 * @subpackage  Gutenberg\Blocks
 * @copyright   Copyright (c) 2021, WeCodeArt Framework
 * @since		5.0.0
 * @version		5.0.0
 */

namespace WeCodeArt\Gutenberg\Blocks\Design;

defined( 'ABSPATH' ) || exit();

use WeCodeArt\Markup;
use WeCodeArt\Markup\SVG;
use WeCodeArt\Singleton;
use WeCodeArt\Gutenberg\Blocks\Dynamic;
use function WeCodeArt\Functions\get_prop;

/**
 * Gutenberg Buttons blocks.
 */
class Buttons extends Dynamic {

	use Singleton;

	/**
	 * Block namespace.
	 *
	 * @var string
	 */
	protected $namespace = 'core';

	/**
	 * Block name.
	 *
	 * @var string
	 */
	protected $block_name = 'buttons';

	/**
	 * Init
	 */
	public function init() {
		register_block_style( $this->get_block_type(), [
			'name' 	=> 'group',
            'label'	=> __( 'Group', 'wecodeart' ),
		] );
	}

	/**
	 * Shortcircuit Register
	 */
	public function register() {}

	/**
	 * Block styles
	 *
	 * @return 	string 	The block styles.
	 */
	public function styles() {
		return "
		.wp-block-buttons {
			display: flex;
			flex-flow: row wrap;
			--wca-button-gutter: 10px;
			margin: 0 calc( var(--wca-button-gutter) * -1 );
		}
		.wp-block-buttons.is-style-group {
			vertical-align: middle;
			--wca-button-gutter: 0;
		}
		.wp-block-buttons.is-style-group:not(.is-vertical) .wp-block-button:not(:first-child) .wp-block-button__link {
			border-left: 0;
			border-top-left-radius: 0;
			border-bottom-left-radius: 0;
		}
		.wp-block-buttons.is-style-group:not(.is-vertical) .wp-block-button:not(:last-child) .wp-block-button__link {
			border-top-right-radius: 0;
			border-bottom-right-radius: 0;
		}
		.wp-block-buttons.is-style-group.is-vertical .wp-block-button {
			margin-bottom: 0;
		}
		.wp-block-buttons.is-style-group.is-vertical .wp-block-button:not(:first-child) {
			margin-top: -1px;
		}
		.wp-block-buttons.is-style-group.is-vertical .wp-block-button:not(:first-child) .wp-block-button__link {
			border-top-left-radius: 0;
			border-top-right-radius: 0;
		}
		.wp-block-buttons.is-style-group.is-vertical .wp-block-button:not(:last-child) .wp-block-button__link {
			border-bottom-left-radius: 0;
			border-bottom-right-radius: 0;
		}
		.wp-block-buttons.is-vertical {
			flex-direction: column;
			align-items: flex-start;
			justify-content: center;
			margin-bottom: 1rem;
		}
		.wp-block-buttons.is-vertical .wp-block-button:last-child {
			margin-bottom: 0;
		}
		.wp-block-buttons.is-content-justification-left {
			justify-content: flex-start;
		}
		.wp-block-buttons.is-content-justification-left.is-vertical {
			align-items: flex-start;
		}
		.wp-block-buttons.is-content-justification-center {
			justify-content: center;
		}
		.wp-block-buttons.is-content-justification-center.is-vertical {
			align-items: center;
		}
		.wp-block-buttons.is-content-justification-right {
			justify-content: flex-end;
		}
		.wp-block-buttons.is-content-justification-right.is-vertical {
			align-items: flex-end;
		}
		.wp-block-buttons.is-content-justification-space-between {
			justify-content: space-between;
		}
		.wp-block-buttons .wp-block-button {
			position: relative;
			display: inline-block;
			padding: 0 var(--wca-button-gutter);
			margin-bottom: 1rem;
		}
		.wp-block-buttons .wp-block-button:hover,
		.wp-block-buttons .wp-block-button__link:focus,
		.wp-block-buttons .wp-block-button__link:active,
		.wp-block-buttons .wp-block-button__link.active {
			z-index: 1;
		}
		";
	}
}
