<?php
/**
 * WeCodeArt Framework
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package		WeCodeArt Framework
 * @subpackage  Gutenberg\Blocks
 * @copyright   Copyright (c) 2021, WeCodeArt Framework
 * @since		5.0.0
 * @version		5.0.0
 */

namespace WeCodeArt\Gutenberg\Blocks\Design;

defined( 'ABSPATH' ) || exit();

use WeCodeArt\Markup;
use WeCodeArt\Singleton;
use WeCodeArt\Gutenberg\Blocks\Dynamic;
use function WeCodeArt\Functions\get_prop;

/**
 * Gutenberg Separator block.
 */
class Separator extends Dynamic {

	use Singleton;

	/**
	 * Block namespace.
	 *
	 * @var string
	 */
	protected $namespace = 'core';

	/**
	 * Block name.
	 *
	 * @var string
	 */
	protected $block_name = 'separator';

	/**
	 * Init
	 */
	public function init() {
		register_block_style( $this->get_block_type(), [
			'name' 	=> 'faded',
            'label'	=> __( 'Faded', 'wecodeart' ),
		] );
	}

	/**
	 * Shortcircuit Register
	 */
	public function register() {}

	/**
	 * Block styles
	 *
	 * @return 	string 	The block styles.
	 */
	public function styles() {
		return '
		.wp-block-separator.is-style-faded {
			background: linear-gradient(to right, transparent, currentColor, transparent)!important;
			opacity: 1;
		}
		.wp-block-separator.is-style-wide {
			border-bottom-width: 1px;
		}
		.wp-block-separator.is-style-dots {
			background: none !important;
			border: none;
			text-align: center;
			max-width: none;
			line-height: 1;
			height: auto;
			opacity: 1;
		}
		.wp-block-separator.is-style-dots::before {
			content: "\00b7 \00b7 \00b7";
			color: currentColor;
			font-size: 1.5rem;
			letter-spacing: 2em;
			padding-left: 2em;
			font-family: serif;
		}
		';
	}
}
