<?php
/**
 * WeCodeArt Framework
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package		WeCodeArt Framework
 * @subpackage  Gutenberg\Blocks
 * @copyright   Copyright (c) 2021, WeCodeArt Framework
 * @since		5.0.0
 * @version		5.0.0
 */

namespace WeCodeArt\Gutenberg\Blocks\Media;

defined( 'ABSPATH' ) || exit();

use WeCodeArt\Markup;
use WeCodeArt\Markup\SVG;
use WeCodeArt\Singleton;
use WeCodeArt\Gutenberg\Blocks\Dynamic;
use function WeCodeArt\Functions\get_prop;

/**
 * Gutenberg File block.
 */
class File extends Dynamic {

	use Singleton;

	/**
	 * Block namespace.
	 *
	 * @var string
	 */
	protected $namespace = 'core';

	/**
	 * Block name.
	 *
	 * @var string
	 */
	protected $block_name = 'file';

	/**
	 * Shortcircuit Register
	 */
	public function register() {
		// add_filter( 'render_block_core/file', [ $this, 'render' ], 10, 2 );
	}

	/**
	 * Dynamically renders the `core/file` block.
	 *
	 * @param 	string 	$content 	The block markup.
	 * @param 	array 	$block 		The parsed block.
	 *
	 * @return 	string 	The block markup.
	 */
	public function render( $content = '', $block = [], $data = null ) {
		$exclude = [
			'btn-primary',
			'btn-secondary',
			'btn-success',
			'btn-danger',
			'btn-warning',
			'btn-light',
			'btn-dark',
			'btn-info',
		];

		$attributes = get_prop( $block, 'attrs', [] );

		$classes = explode( ' ', get_prop( $attributes, 'className', '' ) );

		$matched = array_intersect( $classes, $exclude );
		$ommited = array_diff( $classes, $exclude );

		$doc = $this->load_html( $content );

		// Wrapper Changes
		$wrapper	= $doc->getElementsByTagName( 'div' )->item(0);
		$classname 	= implode( ' ', array_merge( [ 'wp-block-file', 'btn-group' ], array_filter( $ommited ) ) );
		
		$wrapper->setAttribute( 'class', $classname );
		
		// Button Changes
		$links	= $wrapper->getElementsByTagName( 'a' );
		foreach( $links as $link ) {
			if( $link->getAttribute( 'class' ) === 'wp-block-file__button' ) {
				$btn_class  = [ 'wp-block-file__button', 'btn' ];
	
				if( ! empty( $matched ) ) {
					$btn_class = array_merge( $btn_class, $matched );
				} else {
					$btn_class[] = 'btn-dark';
				}

				$link->setAttribute( 'class', join( ' ', $btn_class ) );
			} else {
				$link->setAttribute( 'class', join( ' ', [ 'wp-block-file__button', 'btn', 'btn-outline-dark' ] ) );
			}
		}

		return $doc->saveHTML();
	}
}
