<?php
/**
 * WeCodeArt Framework
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package		WeCodeArt Framework
 * @subpackage  Gutenberg\Blocks
 * @copyright   Copyright (c) 2021, WeCodeArt Framework
 * @since		5.0.0
 * @version		5.0.0
 */

namespace WeCodeArt\Gutenberg\Blocks\Text;

defined( 'ABSPATH' ) || exit();

use WeCodeArt\Markup;
use WeCodeArt\Singleton;
use WeCodeArt\Gutenberg\Blocks\Dynamic;
use function WeCodeArt\Functions\get_prop;

/**
 * Gutenberg Table block.
 */
class Table extends Dynamic {

	use Singleton;

	/**
	 * Block namespace.
	 *
	 * @var string
	 */
	protected $namespace = 'core';

	/**
	 * Block name.
	 *
	 * @var string
	 */
	protected $block_name = 'table';

	/**
	 * Shortcircuit Register
	 */
	public function register() {
		add_filter( 'render_block_core/table', [ $this, 'render' ], 10, 2 );
	}

	/**
	 * Dynamically renders the `core/table` block.
	 *
	 * @param 	string 	$content 	The block markup.
	 * @param 	array 	$block 		The parsed block.
	 *
	 * @return 	string 	The block markup.
	 */
	public function render( $content = '', $block = [], $data = null ) {
		$attributes = get_prop( $block, 'attrs', [] );

		$exclude = [
			'table-bordered',
			'table-borderless',
			'table-dark',
			'table-sm',
			'table-lg',
			'table-striped',
			'table-hover',
		];
		
		$classes = explode( ' ', get_prop( $attributes, 'className', '' ) );

		$border = get_prop( $attributes, [ 'style', 'border' ], [] );

		$matched = array_intersect( $classes, $exclude );
		$ommited = array_diff( $classes, $exclude );

		$doc = $this->load_html( $content );

		// Wrapper Changes
		$wrapper	= $doc->getElementsByTagName( 'figure' )->item(0);
		$classname 	= $wrapper->getAttribute( 'class' );
		$wrapper->setAttribute( 'class', join( ' ', array_filter( array_merge( explode( ' ', $classname ), $ommited ) ) ) );
		
		// Table Changes
		$table 		= $wrapper->getElementsByTagName( 'table' )->item(0);
		$table_cls  = [ 'table' ];
		
		if( $value = get_prop( $border, 'style', 'none' ) ) {
			$table_cls[] = $value === 'none' ? 'table-borderless' : 'table-bordered';
		}

		if( in_array( 'is-style-stripes', $classes, true ) ) {
			$table_cls[] = 'table-striped';
		}
		
		if( in_array( 'is-style-hover', $classes, true ) ) {
			$table_cls[] = 'table-hover';
		}

		if( ! empty( $matched ) ) {
			$table_cls = array_merge( $table_cls, $matched );
		}
		
		if( $dom_cls = $table->getAttribute( 'class' ) ) {
			$table_cls[] = $dom_cls;
		}

		// Set Table Classname
		$table->setAttribute( 'class', join( ' ', $table_cls ) );

		return $this->save_html( $doc->saveHTML() );
	}

	/**
	 * Block styles
	 *
	 * @return 	string 	The block styles.
	 */
	public function styles() {
		return "
		.wp-block-table.alignleft,
		.wp-block-table.aligncenter,
		.wp-block-table.alignright {
			display: table;
			width: auto;
		}
		.wp-block-table .has-fixed-layout {
			table-layout: fixed;
		}
		.wp-block-table thead,
		.wp-block-table tbody,
		.wp-block-table tfoot,
		.wp-block-table .table-bordered > :not(caption) > *,
		.wp-block-table .table-bordered > :not(caption) > * > * {
			border-color: inherit;
			border-style: inherit;
			border-width: inherit;
		}
		.wp-block-table td,
		.wp-block-table th {
			word-break: break-word;
		}
		.wp-block-table .table-striped tbody tr {
			--wca-table-striped-color: inherit;
		}
		";
	}
}
