<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Support\FileSystem
 * @copyright   Copyright (c) 2021, WeCodeArt Framework
 * @since 		5.0.0
 * @version		5.0.0
 */

namespace WeCodeArt\Support;

defined( 'ABSPATH' ) || exit;

use WeCodeArt\Singleton;

/**
 * Manages the Theme Uploads.
 */
class FileSystem {
	
	use Singleton;

	/**
	 * Current folder
	 *
	 * @since 	5.0.0
	 * @var 	string
	 */
	public	$folder = '';

	/**
	 * Send to contructor.
	 */
	public function init() {
		$this->set_folder();
	}

	/**
	 * Function to set folder in WordPress Filesystem.
	 *
	 * @since   5.0.0
	 *
	 * @return  bool
	 */
	public function set_folder( $folder = '' ) {
		$wp_upload_dir = wp_get_upload_dir();

		if ( ! is_writable( $wp_upload_dir['basedir'] ) ) {
			return false;
		}

		$this->folder = implode( '/', array_filter( [ $wp_upload_dir['basedir'], 'wecodeart', $folder ] ) );

		wp_mkdir_p( wp_normalize_path( $this->folder ) );

		return $this;
	}

	/**
	 * Function to create file from WordPress Filesystem.
	 *
	 * @since   5.0.0
	 *
	 * @return  bool
	 */
	public function create_file( $filename, $content ) {
		// Delete old file
		$this->delete_file( $filename );

		// Create new file
		return file_put_contents( $this->get_file_url( $filename ), $content );
	}

	/**
	 * Function to delete file from WordPress Filesystem.
	 *
	 * @since   5.0.0
	 *
	 * @return  bool
	 */
	public function delete_file( $filename ) {
		// If no specific file, bail
		if ( $this->has_file( $filename ) ) {
			return unlink( $this->get_file_url( $filename ) );
		}
	}

	/**
	 * Check if we have a file
	 *
	 * @since   5.0.0
	 *
	 * @return  bool
	 */
	public function has_file( $file ) {
		return is_file( $this->get_file_url( $file ) );
	}

	/**
	 * Get File url.
	 *
	 * @return  string File url.
	 */
	public function get_file_url( $filename, $link = false ) {
		$file = implode( '/', array_filter( [ $this->folder, $filename ] ) );
		
		if( $link ) {
			$file = str_replace( WP_CONTENT_DIR, content_url(), $file );
		}

		return $file;
	}
}